@@ -1,12 +1,17 @@
+import logging
 import string
 from typing import Any, Callable, Dict, Optional, Tuple
 
 import requests
 
+from . import __app_name__
 from .s3 import get_real_url, reserve_url
 from .util import ResultProcess, generate_token
 
 
+logger = logging.getLogger(__app_name__)
+
+
 class ToDusClient:
     def __init__(
         self, version_name: str = "0.40.16", version_code: str = "21820"
@@ -36,13 +41,12 @@ class ToDusClient:
             return self._process.get_result(timeout)
         except (AttributeError, PermissionError) as ex:
             # AttributeError: Can't pickle local object 'ToDusClient.login.<locals>.task'
-            raise ex
-        finally:
+            logger.exception(ex)
             self.abort()
 
     def abort(self) -> None:
         if self._process is not None and self._process.is_alive():
-            self._process.kill()  # type: ignore [attr-defined]
+            self._process.terminate()
             self._process.abort()
             self._process = None
 
@@ -182,7 +186,9 @@ class ToDusClient:
                 file.write(resp.content)
             return size
 
-    def download_file(self, token: str, url: str, path: str) -> int:
+    def download_file(
+        self, token: str, url: str, path: str, down_timeout: float = 60 * 20
+    ) -> int:
         """Download file URL.
 
         Returns the file size.
@@ -190,4 +196,4 @@ class ToDusClient:
         kwargs = {"args": (token, url)}
         url = self._run_task(self.task_download_1, self.timeout, **kwargs)
         kwargs = {"args": (token, url, path)}  # type: ignore [dict-item]
-        return self._run_task(self.task_download_2, self.timeout, **kwargs)
+        return self._run_task(self.task_download_2, down_timeout, **kwargs)
